@@ -1,6 +1,6 @@
 #' Fitting Bayesian VAR(p) of Horseshoe Prior
 #' 
-#' `r lifecycle::badge("experimental")` This function fits BVAR(p) with horseshoe prior.
+#' `r lifecycle::badge("deprecated")` This function fits BVAR(p) with horseshoe prior.
 #' 
 #' @param y Time series data of which columns indicate the variables
 #' @param p VAR lag
@@ -11,45 +11,43 @@
 #' @param bayes_spec Horseshoe initialization specification by [set_horseshoe()].
 #' @param include_mean Add constant term (Default: `TRUE`) or not (`FALSE`)
 #' @param minnesota Minnesota type
-#' @param algo Ordinary gibbs sampling (`"gibbs"`) or blocked gibbs (Default: `"block"`).
+#' @param algo Ordinary gibbs sampling (`gibbs`) or blocked gibbs (Default: `block`).
 #' @param verbose Print the progress bar in the console. By default, `FALSE`.
 #' @param num_thread `r lifecycle::badge("experimental")` Number of threads
 #' @return `bvar_horseshoe` returns an object named `bvarhs` [class].
 #' It is a list with the following components:
 #' 
 #' \describe{
-#'   \item{alpha_record}{MCMC trace for vectorized coefficients (alpha \eqn{\alpha}) with [posterior::draws_df] format.}
-#'   \item{lambda_record}{MCMC trace for local shrinkage level (lambda \eqn{\lambda}) with [posterior::draws_df] format.}
-#'   \item{tau_record}{MCMC trace for global shrinkage level (tau \eqn{\tau}) with [posterior::draws_df] format.}
-#'   \item{psi_record}{MCMC trace for precision matrix (psi \eqn{\Psi}) with [list] format.}
-#'   \item{chain}{The numer of chains}
 #'   \item{coefficients}{Posterior mean of VAR coefficients.}
-#'   \item{psi_posterior}{Posterior mean of precision matrix \eqn{\Psi}}
 #'   \item{covmat}{Posterior mean of covariance matrix}
-#'   \item{omega_record}{MCMC trace for diagonal element of \eqn{\Psi} (omega) with [posterior::draws_df] format.}
-#'   \item{eta_record}{MCMC trace for upper triangular element of \eqn{\Psi} (eta) with [posterior::draws_df] format.}
+#'   \item{psi_posterior}{Posterior mean of precision matrix \eqn{\Psi}}
+#'   \item{pip}{Posterior inclusion probabilities.}
 #'   \item{param}{[posterior::draws_df] with every variable: alpha, lambda, tau, omega, and eta}
+#'   \item{param_names}{Name of every parameter.}
 #'   \item{df}{Numer of Coefficients: `mp + 1` or `mp`}
 #'   \item{p}{Lag of VAR}
 #'   \item{m}{Dimension of the data}
 #'   \item{obs}{Sample size used when training = `totobs` - `p`}
 #'   \item{totobs}{Total number of the observation}
 #'   \item{call}{Matched call}
-#'   \item{process}{Description of the model, e.g. `"VAR_Horseshoe"`}
-#'   \item{type}{include constant term (`"const"`) or not (`"none"`)}
-#'   \item{algo}{Usual Gibbs sampling (`"gibbs"`) or fast sampling (`"fast"`)}
+#'   \item{process}{Description of the model, e.g. `VAR_Horseshoe`}
+#'   \item{type}{include constant term (`const`) or not (`none`)}
+#'   \item{algo}{Usual Gibbs sampling (`gibbs`) or fast sampling (`fast`)}
 #'   \item{spec}{Horseshoe specification defined by [set_horseshoe()]}
+#'   \item{chain}{The numer of chains}
 #'   \item{iter}{Total iterations}
 #'   \item{burn}{Burn-in}
 #'   \item{thin}{Thinning}
+#'   \item{group}{Indicators for group.}
+#'   \item{num_group}{Number of groups.}
 #'   \item{y0}{\eqn{Y_0}}
 #'   \item{design}{\eqn{X_0}}
 #'   \item{y}{Raw input}
 #' }
 #' @references 
-#' Carvalho, C. M., Polson, N. G., & Scott, J. G. (2010). *The horseshoe estimator for sparse signals*. Biometrika, 97(2), 465–480.
+#' Carvalho, C. M., Polson, N. G., & Scott, J. G. (2010). *The horseshoe estimator for sparse signals*. Biometrika, 97(2), 465-480.
 #' 
-#' Makalic, E., & Schmidt, D. F. (2016). *A Simple Sampler for the Horseshoe Estimator*. IEEE Signal Processing Letters, 23(1), 179–182.
+#' Makalic, E., & Schmidt, D. F. (2016). *A Simple Sampler for the Horseshoe Estimator*. IEEE Signal Processing Letters, 23(1), 179-182.
 #' @importFrom posterior as_draws_df bind_draws
 #' @importFrom stats cov
 #' @order 1
@@ -66,6 +64,7 @@ bvar_horseshoe <- function(y,
                            algo = c("block", "gibbs"),
                            verbose = FALSE,
                            num_thread = 1) {
+  deprecate_warn("2.0.1", "bvar_horseshoe()", "var_bayes()")
   if (!all(apply(y, 2, is.numeric))) {
     stop("Every column must be numeric class.")
   }
@@ -124,7 +123,8 @@ bvar_horseshoe <- function(y,
     include_mean = include_mean
   )
   grp_id <- unique(c(glob_idmat))
-  global_sparsity <- rep(bayes_spec$global_sparsity, length(grp_id))
+  # global_sparsity <- rep(bayes_spec$global_sparsity, length(grp_id))
+  bayes_spec$group_sparsity <- rep(bayes_spec$group_sparsity, length(grp_id))
   # MCMC-----------------------------
   num_design <- nrow(Y0)
   fast <- FALSE
@@ -145,7 +145,8 @@ bvar_horseshoe <- function(y,
     x = X0,
     y = Y0,
     init_local = bayes_spec$local_sparsity,
-    init_global = global_sparsity,
+    init_group = bayes_spec$group_sparsity,
+    init_global = bayes_spec$global_sparsity,
     init_sigma = 1,
     grp_id = grp_id,
     grp_mat = glob_idmat,
@@ -199,64 +200,17 @@ bvar_horseshoe <- function(y,
     )
   }
   res[rec_names] <- lapply(res[rec_names], as_draws_df)
-  # thin_id <- seq(from = 1, to = num_iter - num_burn, by = thinning)
-  # res$alpha_record <- res$alpha_record[thin_id,]
-  # colnames(res$alpha_record) <- paste0(
-  #   "alpha[",
-  #   seq_len(ncol(res$alpha_record)),
-  #   "]"
-  # )
-  # res$coefficients <- 
-  #   colMeans(res$alpha_record) %>% 
-  #   matrix(ncol = dim_data)
-  # colnames(res$coefficients) <- name_var
-  # rownames(res$coefficients) <- name_lag
-  # res$alpha_record <- as_draws_df(res$alpha_record)
-  # if (minnesota) {
-  #   res$tau_record <- res$tau_record[thin_id,]
-  #   colnames(res$tau_record) <- paste0(
-  #     "tau[",
-  #     seq_len(ncol(res$tau_record)),
-  #     "]"
-  #   )
-  # } else {
-  #   res$tau_record <- as.matrix(res$tau_record[thin_id])
-  #   colnames(res$tau_record) <- "tau"
-  # }
-  # res$tau_record <- as_draws_df(res$tau_record)
-  # res$lambda_record <- res$lambda_record[thin_id,]
-  # colnames(res$lambda_record) <- paste0(
-  #   "lambda[",
-  #   seq_len(ncol(res$lambda_record)),
-  #   "]"
-  # )
-  # res$lambda_record <- as_draws_df(res$lambda_record)
-  # res$covmat <- mean(res$sigma) * diag(dim_data)
-  # res$psi_posterior <- diag(dim_data) / mean(res$sigma)
-  # colnames(res$covmat) <- name_var
-  # rownames(res$covmat) <- name_var
-  # colnames(res$psi_posterior) <- name_var
-  # rownames(res$psi_posterior) <- name_var
-  # res$sigma_record <- as.matrix(res$sigma_record[thin_id])
-  # colnames(res$sigma_record) <- "sigma"
-  # res$sigma_record <- as_draws_df(res$sigma_record)
-  # res$kappa_record <- res$kappa_record[thin_id,]
-  # colnames(res$kappa_record) <- paste0(
-  #   "kappa[",
-  #   seq_len(ncol(res$kappa_record)),
-  #   "]"
-  # )
-  # res$pip <- matrix(colMeans(res$kappa_record), ncol = dim_data)
-  # colnames(res$pip) <- name_var
-  # rownames(res$pip) <- name_lag
-  # res$kappa_record <- as_draws_df(res$kappa_record)
   # Parameters-----------------
   res$param <- bind_draws(
     res$alpha_record,
     res$lambda_record,
+    res$eta_record,
     res$tau_record,
-    res$sigma_record
+    res$sigma_record,
+    res$kappa_record
   )
+  res[rec_names] <- NULL
+  res$param_names <- param_names
   # variables------------
   res$df <- ncol(X0)
   res$p <- p
