@@ -220,11 +220,12 @@ forecast_roll.normaliw <- function(object, n_ahead, y_test, num_thread = 1, use_
 }
 
 #' @rdname forecast_roll
+#' @param level Specify alpha of confidence interval level 100(1 - alpha) percentage. By default, .05.
 #' @param sparse `r lifecycle::badge("experimental")` Apply restriction. By default, `FALSE`.
 #' @param lpl `r lifecycle::badge("experimental")` Compute log-predictive likelihood (LPL). By default, `FALSE`.
 #' @param use_fit `r lifecycle::badge("experimental")` Use `object` result for the first window. By default, `TRUE`.
 #' @export
-forecast_roll.ldltmod <- function(object, n_ahead, y_test, num_thread = 1, sparse = FALSE, lpl = FALSE, use_fit = TRUE, ...) {
+forecast_roll.ldltmod <- function(object, n_ahead, y_test, num_thread = 1, level = .05, sparse = FALSE, lpl = FALSE, use_fit = TRUE, ...) {
   y <- object$y
   if (!is.null(colnames(y))) {
     name_var <- colnames(y)
@@ -256,21 +257,12 @@ forecast_roll.ldltmod <- function(object, n_ahead, y_test, num_thread = 1, spars
   # if (num_thread > num_chains && num_chains != 1) {
   #   warning(sprintf("'num_thread' > MCMC chain will use not every thread. Specify as 'num_thread' <= 'object$chain' = %d.", num_chains))
   # }
-  if (num_horizon * num_chains %/% num_thread == 0) {
-    warning(sprintf("OpenMP cannot divide the iterations as integer. Use divisor of ('nrow(y_test) - n_ahead + 1') * 'num_thread' <= 'object$chain' = %d", num_horizon * num_chains))
-  }
-  chunk_size <- num_horizon * num_chains %/% num_thread # default setting of OpenMP schedule(static)
-  if (chunk_size == 0) {
-    chunk_size <- 1
-  }
-  # if (num_horizon > num_chains && chunk_size > num_chains) {
-  #   chunk_size <- min(
-  #     num_chains,
-  #     (num_horizon %/% num_thread) * num_chains
-  #   )
-  #   if (chunk_size == 0) {
-  #     chunk_size <- 1
-  #   }
+  # if (num_horizon * num_chains %/% num_thread == 0) {
+  #   warning(sprintf("OpenMP cannot divide the iterations as integer. Use divisor of ('nrow(y_test) - n_ahead + 1') * 'num_thread' <= 'object$chain' = %d", num_horizon * num_chains))
+  # }
+  # chunk_size <- num_horizon * num_chains %/% num_thread # default setting of OpenMP schedule(static)
+  # if (chunk_size == 0) {
+  #   chunk_size <- 1
   # }
   ci_lev <- 0
   if (is.numeric(sparse)) {
@@ -326,7 +318,7 @@ forecast_roll.ldltmod <- function(object, n_ahead, y_test, num_thread = 1, spars
         lpl,
         sample.int(.Machine$integer.max, size = num_chains * num_horizon) %>% matrix(ncol = num_chains),
         sample.int(.Machine$integer.max, size = num_chains),
-        num_thread, chunk_size
+        num_thread
       )
     },
     "bvharldlt" = {
@@ -371,12 +363,12 @@ forecast_roll.ldltmod <- function(object, n_ahead, y_test, num_thread = 1, spars
         lpl,
         sample.int(.Machine$integer.max, size = num_chains * num_horizon) %>% matrix(ncol = num_chains),
         sample.int(.Machine$integer.max, size = num_chains),
-        num_thread, chunk_size
+        num_thread
       )
     }
   )
-  # num_draw <- nrow(object$a_record) # concatenate multiple chains
-  num_draw <- nrow(object$param) / num_chains
+  num_draw <- nrow(object$param) # concatenate multiple chains
+  # num_draw <- nrow(object$param) / num_chains
   if (lpl) {
     lpl_val <- res_mat$lpl
     res_mat$lpl <- NULL
@@ -404,7 +396,7 @@ forecast_roll.ldltmod <- function(object, n_ahead, y_test, num_thread = 1, spars
     lapply(function(res) {
       unlist(res) %>%
         array(dim = c(1, object$m, num_draw)) %>%
-        apply(c(1, 2), quantile, probs = .05 / 2)
+        apply(c(1, 2), quantile, probs = level / 2)
     }) %>%
     do.call(rbind, .)
   colnames(lower_quantile) <- name_var
@@ -413,7 +405,7 @@ forecast_roll.ldltmod <- function(object, n_ahead, y_test, num_thread = 1, spars
     lapply(function(res) {
       unlist(res) %>%
         array(dim = c(1, object$m, num_draw)) %>%
-        apply(c(1, 2), quantile, probs = 1 - .05 / 2)
+        apply(c(1, 2), quantile, probs = 1 - level / 2)
     }) %>%
     do.call(rbind, .)
   colnames(upper_quantile) <- name_var
@@ -436,12 +428,13 @@ forecast_roll.ldltmod <- function(object, n_ahead, y_test, num_thread = 1, spars
 }
 
 #' @rdname forecast_roll
+#' @param level Specify alpha of confidence interval level 100(1 - alpha) percentage. By default, .05.
 #' @param use_sv Use SV term
 #' @param sparse `r lifecycle::badge("experimental")` Apply restriction. By default, `FALSE`.
 #' @param lpl `r lifecycle::badge("experimental")` Compute log-predictive likelihood (LPL). By default, `FALSE`.
 #' @param use_fit `r lifecycle::badge("experimental")` Use `object` result for the first window. By default, `TRUE`.
 #' @export
-forecast_roll.svmod <- function(object, n_ahead, y_test, num_thread = 1, use_sv = TRUE, sparse = FALSE, lpl = FALSE, use_fit = TRUE, ...) {
+forecast_roll.svmod <- function(object, n_ahead, y_test, num_thread = 1, level = .05, use_sv = TRUE, sparse = FALSE, lpl = FALSE, use_fit = TRUE, ...) {
   y <- object$y
   if (!is.null(colnames(y))) {
     name_var <- colnames(y)
@@ -473,21 +466,12 @@ forecast_roll.svmod <- function(object, n_ahead, y_test, num_thread = 1, use_sv
   # if (num_thread > num_chains && num_chains != 1) {
   #   warning(sprintf("'num_thread' > MCMC chain will use not every thread. Specify as 'num_thread' <= 'object$chain' = %d.", num_chains))
   # }
-  if (num_horizon * num_chains %/% num_thread == 0) {
-    warning(sprintf("OpenMP cannot divide the iterations as integer. Use divisor of ('nrow(y_test) - n_ahead + 1') * 'num_thread' <= 'object$chain' = %d", num_horizon * num_chains))
-  }
-  chunk_size <- num_horizon * num_chains %/% num_thread # default setting of OpenMP schedule(static)
-  if (chunk_size == 0) {
-    chunk_size <- 1
-  }
-  # if (num_horizon > num_chains && chunk_size > num_chains) {
-  #   chunk_size <- min(
-  #     num_chains,
-  #     (num_horizon %/% num_thread) * num_chains
-  #   )
-  #   if (chunk_size == 0) {
-  #     chunk_size <- 1
-  #   }
+  # if (num_horizon * num_chains %/% num_thread == 0) {
+  #   warning(sprintf("OpenMP cannot divide the iterations as integer. Use divisor of ('nrow(y_test) - n_ahead + 1') * 'num_thread' <= 'object$chain' = %d", num_horizon * num_chains))
+  # }
+  # chunk_size <- num_horizon * num_chains %/% num_thread # default setting of OpenMP schedule(static)
+  # if (chunk_size == 0) {
+  #   chunk_size <- 1
   # }
   ci_lev <- 0
   if (is.numeric(sparse)) {
@@ -544,7 +528,7 @@ forecast_roll.svmod <- function(object, n_ahead, y_test, num_thread = 1, use_sv
         lpl,
         sample.int(.Machine$integer.max, size = num_chains * num_horizon) %>% matrix(ncol = num_chains),
         sample.int(.Machine$integer.max, size = num_chains),
-        num_thread, chunk_size
+        num_thread
       )
     },
     "bvharsv" = {
@@ -589,12 +573,12 @@ forecast_roll.svmod <- function(object, n_ahead, y_test, num_thread = 1, use_sv
         lpl,
         sample.int(.Machine$integer.max, size = num_chains * num_horizon) %>% matrix(ncol = num_chains),
         sample.int(.Machine$integer.max, size = num_chains),
-        num_thread, chunk_size
+        num_thread
       )
     }
   )
-  # num_draw <- nrow(object$a_record) # concatenate multiple chains
-  num_draw <- nrow(object$param) / num_chains
+  num_draw <- nrow(object$param) # concatenate multiple chains
+  # num_draw <- nrow(object$param) / num_chains
   if (lpl) {
     lpl_val <- res_mat$lpl
     res_mat$lpl <- NULL
@@ -622,7 +606,7 @@ forecast_roll.svmod <- function(object, n_ahead, y_test, num_thread = 1, use_sv
     lapply(function(res) {
       unlist(res) %>%
         array(dim = c(1, object$m, num_draw)) %>%
-        apply(c(1, 2), quantile, probs = .05 / 2)
+        apply(c(1, 2), quantile, probs = level / 2)
     }) %>%
     do.call(rbind, .)
   colnames(lower_quantile) <- name_var
@@ -631,7 +615,7 @@ forecast_roll.svmod <- function(object, n_ahead, y_test, num_thread = 1, use_sv
     lapply(function(res) {
       unlist(res) %>%
         array(dim = c(1, object$m, num_draw)) %>%
-        apply(c(1, 2), quantile, probs = 1 - .05 / 2)
+        apply(c(1, 2), quantile, probs = 1 - level / 2)
     }) %>%
     do.call(rbind, .)
   colnames(upper_quantile) <- name_var
@@ -816,11 +800,12 @@ forecast_expand.normaliw <- function(object, n_ahead, y_test, num_thread = 1, us
 }
 
 #' @rdname forecast_expand
+#' @param level Specify alpha of confidence interval level 100(1 - alpha) percentage. By default, .05.
 #' @param sparse `r lifecycle::badge("experimental")` Apply restriction. By default, `FALSE`.
 #' @param lpl `r lifecycle::badge("experimental")` Compute log-predictive likelihood (LPL). By default, `FALSE`.
 #' @param use_fit `r lifecycle::badge("experimental")` Use `object` result for the first window. By default, `TRUE`.
 #' @export
-forecast_expand.ldltmod <- function(object, n_ahead, y_test, num_thread = 1, sparse = FALSE, lpl = FALSE, use_fit = TRUE, ...) {
+forecast_expand.ldltmod <- function(object, n_ahead, y_test, num_thread = 1, level = .05, sparse = FALSE, lpl = FALSE, use_fit = TRUE, ...) {
   y <- object$y
   if (!is.null(colnames(y))) {
     name_var <- colnames(y)
@@ -852,22 +837,13 @@ forecast_expand.ldltmod <- function(object, n_ahead, y_test, num_thread = 1, spa
   # if (num_thread > num_chains && num_chains != 1) {
   #   warning(sprintf("'num_thread' > MCMC chain will use not every thread. Specify as 'num_thread' <= 'object$chain' = %d.", num_chains))
   # }
-  if (num_horizon * num_chains %/% num_thread == 0) {
-    warning(sprintf("OpenMP cannot divide the iterations as integer. Use divisor of ('nrow(y_test) - n_ahead + 1') * 'num_thread' <= 'object$chain' = %d", num_horizon * num_chains))
-  }
+  # if (num_horizon * num_chains %/% num_thread == 0) {
+  #   warning(sprintf("OpenMP cannot divide the iterations as integer. Use divisor of ('nrow(y_test) - n_ahead + 1') * 'num_thread' <= 'object$chain' = %d", num_horizon * num_chains))
+  # }
   # chunk_size <- num_horizon * num_chains %/% num_thread # default setting of OpenMP schedule(static)
-  chunk_size <- num_chains # use inner loop for chain as a chunk in dynamic schedule
-  if (chunk_size == 0) {
-    chunk_size <- 1
-  }
-  # if (num_horizon > num_chains && chunk_size > num_chains) {
-  #   chunk_size <- min(
-  #     num_chains,
-  #     (num_horizon %/% num_thread) * num_chains
-  #   )
-  #   if (chunk_size == 0) {
-  #     chunk_size <- 1
-  #   }
+  # chunk_size <- num_chains # use inner loop for chain as a chunk in dynamic schedule
+  # if (chunk_size == 0) {
+  #   chunk_size <- 1
   # }
   ci_lev <- 0
   if (is.numeric(sparse)) {
@@ -924,7 +900,7 @@ forecast_expand.ldltmod <- function(object, n_ahead, y_test, num_thread = 1, spa
         lpl,
         sample.int(.Machine$integer.max, size = num_chains * num_horizon) %>% matrix(ncol = num_chains),
         sample.int(.Machine$integer.max, size = num_chains),
-        num_thread, chunk_size
+        num_thread
       )
     },
     "bvharldlt" = {
@@ -969,12 +945,12 @@ forecast_expand.ldltmod <- function(object, n_ahead, y_test, num_thread = 1, spa
         lpl,
         sample.int(.Machine$integer.max, size = num_chains * num_horizon) %>% matrix(ncol = num_chains),
         sample.int(.Machine$integer.max, size = num_chains),
-        num_thread, chunk_size
+        num_thread
       )
     }
   )
-  # num_draw <- nrow(object$a_record) # concatenate multiple chains
-  num_draw <- nrow(object$param) / num_chains
+  num_draw <- nrow(object$param) # concatenate multiple chains
+  # num_draw <- nrow(object$param) / num_chains
   if (lpl) {
     lpl_val <- res_mat$lpl
     res_mat$lpl <- NULL
@@ -1011,7 +987,7 @@ forecast_expand.ldltmod <- function(object, n_ahead, y_test, num_thread = 1, spa
     lapply(function(res) {
       unlist(res) %>%
         array(dim = c(1, object$m, num_draw)) %>%
-        apply(c(1, 2), quantile, probs = .05 / 2)
+        apply(c(1, 2), quantile, probs = level / 2)
     }) %>%
     do.call(rbind, .)
   colnames(lower_quantile) <- name_var
@@ -1020,7 +996,7 @@ forecast_expand.ldltmod <- function(object, n_ahead, y_test, num_thread = 1, spa
     lapply(function(res) {
       unlist(res) %>%
         array(dim = c(1, object$m, num_draw)) %>%
-        apply(c(1, 2), quantile, probs = 1 - .05 / 2)
+        apply(c(1, 2), quantile, probs = 1 - level / 2)
     }) %>%
     do.call(rbind, .)
   colnames(upper_quantile) <- name_var
@@ -1043,12 +1019,13 @@ forecast_expand.ldltmod <- function(object, n_ahead, y_test, num_thread = 1, spa
 }
 
 #' @rdname forecast_expand
+#' @param level Specify alpha of confidence interval level 100(1 - alpha) percentage. By default, .05.
 #' @param use_sv Use SV term
 #' @param sparse `r lifecycle::badge("experimental")` Apply restriction. By default, `FALSE`.
 #' @param lpl `r lifecycle::badge("experimental")` Compute log-predictive likelihood (LPL). By default, `FALSE`.
 #' @param use_fit `r lifecycle::badge("experimental")` Use `object` result for the first window. By default, `TRUE`.
 #' @export
-forecast_expand.svmod <- function(object, n_ahead, y_test, num_thread = 1, use_sv = TRUE, sparse = FALSE, lpl = FALSE, use_fit = TRUE, ...) {
+forecast_expand.svmod <- function(object, n_ahead, y_test, num_thread = 1, level = .05, use_sv = TRUE, sparse = FALSE, lpl = FALSE, use_fit = TRUE, ...) {
   y <- object$y
   if (!is.null(colnames(y))) {
     name_var <- colnames(y)
@@ -1080,22 +1057,13 @@ forecast_expand.svmod <- function(object, n_ahead, y_test, num_thread = 1, use_s
   # if (num_thread > num_chains && num_chains != 1) {
   #   warning(sprintf("'num_thread' > MCMC chain will use not every thread. Specify as 'num_thread' <= 'object$chain' = %d.", num_chains))
   # }
-  if (num_horizon * num_chains %/% num_thread == 0) {
-    warning(sprintf("OpenMP cannot divide the iterations as integer. Use divisor of ('nrow(y_test) - n_ahead + 1') * 'num_thread' <= 'object$chain' = %d", num_horizon * num_chains))
-  }
+  # if (num_horizon * num_chains %/% num_thread == 0) {
+  #   warning(sprintf("OpenMP cannot divide the iterations as integer. Use divisor of ('nrow(y_test) - n_ahead + 1') * 'num_thread' <= 'object$chain' = %d", num_horizon * num_chains))
+  # }
   # chunk_size <- num_horizon * num_chains %/% num_thread # default setting of OpenMP schedule(static)
-  chunk_size <- num_chains # use inner loop for chain as a chunk in dynamic schedule
-  if (chunk_size == 0) {
-    chunk_size <- 1
-  }
-  # if (num_horizon > num_chains && chunk_size > num_chains) {
-  #   chunk_size <- min(
-  #     num_chains,
-  #     (num_horizon %/% num_thread) * num_chains
-  #   )
-  #   if (chunk_size == 0) {
-  #     chunk_size <- 1
-  #   }
+  # chunk_size <- num_chains # use inner loop for chain as a chunk in dynamic schedule
+  # if (chunk_size == 0) {
+  #   chunk_size <- 1
   # }
   ci_lev <- 0
   if (is.numeric(sparse)) {
@@ -1152,7 +1120,7 @@ forecast_expand.svmod <- function(object, n_ahead, y_test, num_thread = 1, use_s
         lpl,
         sample.int(.Machine$integer.max, size = num_chains * num_horizon) %>% matrix(ncol = num_chains),
         sample.int(.Machine$integer.max, size = num_chains),
-        num_thread, chunk_size
+        num_thread
       )
     },
     "bvharsv" = {
@@ -1197,12 +1165,12 @@ forecast_expand.svmod <- function(object, n_ahead, y_test, num_thread = 1, use_s
         lpl,
         sample.int(.Machine$integer.max, size = num_chains * num_horizon) %>% matrix(ncol = num_chains),
         sample.int(.Machine$integer.max, size = num_chains),
-        num_thread, chunk_size
+        num_thread
       )
     }
   )
-  # num_draw <- nrow(object$a_record) # concatenate multiple chains
-  num_draw <- nrow(object$param) / num_chains
+  num_draw <- nrow(object$param) # concatenate multiple chains
+  # num_draw <- nrow(object$param) / num_chains
   if (lpl) {
     lpl_val <- res_mat$lpl
     res_mat$lpl <- NULL
@@ -1239,7 +1207,7 @@ forecast_expand.svmod <- function(object, n_ahead, y_test, num_thread = 1, use_s
     lapply(function(res) {
       unlist(res) %>%
         array(dim = c(1, object$m, num_draw)) %>%
-        apply(c(1, 2), quantile, probs = .05 / 2)
+        apply(c(1, 2), quantile, probs = level / 2)
     }) %>%
     do.call(rbind, .)
   colnames(lower_quantile) <- name_var
@@ -1248,7 +1216,7 @@ forecast_expand.svmod <- function(object, n_ahead, y_test, num_thread = 1, use_s
     lapply(function(res) {
       unlist(res) %>%
         array(dim = c(1, object$m, num_draw)) %>%
-        apply(c(1, 2), quantile, probs = 1 - .05 / 2)
+        apply(c(1, 2), quantile, probs = 1 - level / 2)
     }) %>%
     do.call(rbind, .)
   colnames(upper_quantile) <- name_var
