@@ -2,41 +2,6 @@
 #include "bvharprogress.h"
 #include "bvharinterrupt.h"
 
-//' Log of Joint Posterior Density of Hyperparameters
-//' 
-//' This function computes the log of joint posterior density of hyperparameters.
-//' 
-//' @param cand_gamma Candidate value of hyperparameters following Gamma distribution
-//' @param cand_invgam Candidate value of hyperparameters following Inverse Gamma distribution
-//' @param dim Dimension of the time series
-//' @param num_design The number of the data matrix, \eqn{n = T - p}
-//' @param prior_prec Prior precision of Matrix Normal distribution
-//' @param prior_scale Prior scale of Inverse-Wishart distribution
-//' @param mn_prec Posterior precision of Matrix Normal distribution
-//' @param iw_scale Posterior scale of Inverse-Wishart distribution
-//' @param posterior_shape Posterior shape of Inverse-Wishart distribution
-//' @param gamma_shape Shape of hyperprior Gamma distribution
-//' @param gamma_rate Rate of hyperprior Gamma distribution
-//' @param invgam_shape Shape of hyperprior Inverse gamma distribution
-//' @param invgam_scl Scale of hyperprior Inverse gamma distribution
-//' 
-//' @noRd
-// [[Rcpp::export]]
-double jointdens_hyperparam(double cand_gamma, Eigen::VectorXd cand_invgam, int dim, int num_design,
-                            Eigen::MatrixXd prior_prec, Eigen::MatrixXd prior_scale, int prior_shape,
-                            Eigen::MatrixXd mn_prec, Eigen::MatrixXd iw_scale,
-                            int posterior_shape, double gamma_shp, double gamma_rate, double invgam_shp, double invgam_scl) {
-  double res = bvhar::compute_logml(dim, num_design, prior_prec, prior_scale, mn_prec, iw_scale, posterior_shape);
-  res += -dim * num_design / 2.0 * log(M_PI) +
-    bvhar::lmgammafn((prior_shape + num_design) / 2.0, dim) -
-    bvhar::lmgammafn(prior_shape / 2.0, dim); // constant term
-  res += bvhar::gamma_dens(cand_gamma, gamma_shp, 1 / gamma_rate, true); // gamma distribution
-  for (int i = 0; i < cand_invgam.size(); i++) {
-    res += bvhar::invgamma_dens(cand_invgam[i], invgam_shp, invgam_scl, true); // inverse gamma distribution
-  }
-  return res;
-}
-
 //' Metropolis Algorithm for Normal-IW Hierarchical Model
 //' 
 //' This function conducts Metropolis algorithm for Normal-IW Hierarchical BVAR or BVHAR.
@@ -89,17 +54,17 @@ Rcpp::List estimate_hierachical_niw(int num_iter, int num_burn, Eigen::MatrixXd
   prevprior[0] = init_lambda;
   prevprior.segment(1, dim) = init_psi;
   Eigen::VectorXd candprior = Eigen::VectorXd::Zero(1 + dim);
-  Rcpp::List posterior_draw = Rcpp::List::create(
-    Rcpp::Named("mn") = Eigen::MatrixXd::Zero(dim_design, dim),
-    Rcpp::Named("iw") = Eigen::MatrixXd::Zero(dim, dim)
-  );
+  // Rcpp::List posterior_draw = Rcpp::List::create(
+  //   Rcpp::Named("mn") = Eigen::MatrixXd::Zero(dim_design, dim),
+  //   Rcpp::Named("iw") = Eigen::MatrixXd::Zero(dim, dim)
+  // );
+	std::vector<Eigen::MatrixXd> posterior_draw(2);
   double numerator = 0;
   double denom = 0;
   bvhar::bvharprogress bar(num_iter, display_progress);
 	bvhar::bvharinterrupt();
   // Start Metropolis---------------------------------------------
-  typedef Eigen::Matrix<bool, Eigen::Dynamic, 1> VectorXb;
-  VectorXb is_accept(num_iter + 1);
+  bvhar::VectorXb is_accept(num_iter + 1);
   is_accept[0] = true;
   for (int i = 1; i < num_iter + 1; i ++) {
     if (bvhar::bvharinterrupt::is_interrupted()) {
@@ -118,10 +83,14 @@ Rcpp::List estimate_hierachical_niw(int num_iter, int num_burn, Eigen::MatrixXd
     // Candidate ~ N(previous, scaled hessian)
     candprior = Eigen::Map<Eigen::VectorXd>(sim_mgaussian_chol(1, prevprior, gaussian_variance).data(), 1 + dim);
     // log of acceptance rate = numerator - denom
-    numerator = jointdens_hyperparam(candprior[0], candprior.segment(1, dim), dim, num_design, prior_prec, prior_scale, prior_shape,
-                                     mn_prec, iw_scale, posterior_shape, gamma_shp, gamma_rate, invgam_shp, invgam_scl);
-    denom = jointdens_hyperparam(prevprior[0], prevprior.segment(1, dim), dim, num_design,
-                                 prior_prec, prior_scale, prior_shape, mn_prec, iw_scale, posterior_shape, gamma_shp, gamma_rate, invgam_shp, invgam_scl);
+    numerator = bvhar::jointdens_hyperparam(
+			candprior[0], candprior.segment(1, dim), dim, num_design,
+			prior_prec, prior_scale, prior_shape, mn_prec, iw_scale, posterior_shape, gamma_shp, gamma_rate, invgam_shp, invgam_scl
+		);
+    denom = bvhar::jointdens_hyperparam(
+			prevprior[0], prevprior.segment(1, dim), dim, num_design,
+			prior_prec, prior_scale, prior_shape, mn_prec, iw_scale, posterior_shape, gamma_shp, gamma_rate, invgam_shp, invgam_scl
+		);
     is_accept[i] = ( log(bvhar::unif_rand(0, 1)) < std::min(numerator - denom, 0.0) );
     // Update
     if (is_accept[i]) {
@@ -132,9 +101,12 @@ Rcpp::List estimate_hierachical_niw(int num_iter, int num_burn, Eigen::MatrixXd
       psi_record.row(i) = psi_record.row(i - 1);
     }
     // Draw coef and Sigma
-    posterior_draw = sim_mniw(1, mn_mean, mn_prec.inverse(), iw_scale, posterior_shape);
-		coef_record.row(i - 1) = bvhar::vectorize_eigen(Rcpp::as<Eigen::MatrixXd>(posterior_draw["mn"]));
-    sig_record.block((i - 1) * dim, 0, dim, dim) = Rcpp::as<Eigen::MatrixXd>(posterior_draw["iw"]);
+    // posterior_draw = sim_mniw(1, mn_mean, mn_prec.inverse(), iw_scale, posterior_shape);
+		// coef_record.row(i - 1) = bvhar::vectorize_eigen(Rcpp::as<Eigen::MatrixXd>(posterior_draw["mn"]));
+    // sig_record.block((i - 1) * dim, 0, dim, dim) = Rcpp::as<Eigen::MatrixXd>(posterior_draw["iw"]);
+		posterior_draw = bvhar::sim_mn_iw(mn_mean, mn_prec.inverse(), iw_scale, posterior_shape, false);
+		coef_record.row(i - 1) = bvhar::vectorize_eigen(posterior_draw[0]);
+    sig_record.block((i - 1) * dim, 0, dim, dim) = posterior_draw[1];
   }
   return Rcpp::List::create(
     Rcpp::Named("lambda_record") = lam_record.tail(num_iter - num_burn),
