@@ -198,7 +198,6 @@ Rcpp::List forecast_bvharldlt(int num_chains, int month, int step, Eigen::Matrix
 //' @param step Integer, Step to forecast
 //' @param y_test Evaluation time series data period after `y`
 //' @param nthreads Number of threads
-//' @param chunk_size Chunk size for OpenMP static scheduling
 //' 
 //' @noRd
 // [[Rcpp::export]]
@@ -207,7 +206,7 @@ Rcpp::List roll_bvarldlt(Eigen::MatrixXd y, int lag, int num_chains, int num_ite
 											 	 Rcpp::List param_reg, Rcpp::List param_prior, Rcpp::List param_intercept, Rcpp::List param_init, int prior_type,
 											 	 Eigen::VectorXi grp_id, Eigen::VectorXi own_id, Eigen::VectorXi cross_id, Eigen::MatrixXi grp_mat,
 											 	 bool include_mean, int step, Eigen::MatrixXd y_test,
-											 	 bool get_lpl, Eigen::MatrixXi seed_chain, Eigen::VectorXi seed_forecast, int nthreads, int chunk_size) {
+											 	 bool get_lpl, Eigen::MatrixXi seed_chain, Eigen::VectorXi seed_forecast, int nthreads) {
 	int num_window = y.rows();
   int dim = y.cols();
   int num_test = y_test.rows();
@@ -447,7 +446,7 @@ Rcpp::List roll_bvarldlt(Eigen::MatrixXd y, int lag, int num_chains, int num_ite
 		}
 	} else {
 	#ifdef _OPENMP
-		#pragma omp parallel for collapse(2) schedule(static, chunk_size) num_threads(nthreads)
+		#pragma omp parallel for collapse(2) schedule(static, num_chains) num_threads(nthreads)
 	#endif
 		for (int window = 0; window < num_horizon; window++) {
 			for (int chain = 0; chain < num_chains; chain++) {
@@ -493,7 +492,6 @@ Rcpp::List roll_bvarldlt(Eigen::MatrixXd y, int lag, int num_chains, int num_ite
 //' @param step Integer, Step to forecast
 //' @param y_test Evaluation time series data period after `y`
 //' @param nthreads Number of threads
-//' @param chunk_size Chunk size for OpenMP static scheduling
 //' 
 //' @noRd
 // [[Rcpp::export]]
@@ -502,7 +500,7 @@ Rcpp::List roll_bvharldlt(Eigen::MatrixXd y, int week, int month, int num_chains
 											  	Rcpp::List param_reg, Rcpp::List param_prior, Rcpp::List param_intercept, Rcpp::List param_init, int prior_type,
 											  	Eigen::VectorXi grp_id, Eigen::VectorXi own_id, Eigen::VectorXi cross_id, Eigen::MatrixXi grp_mat,
 													bool include_mean, int step, Eigen::MatrixXd y_test,
-											  	bool get_lpl, Eigen::MatrixXi seed_chain, Eigen::VectorXi seed_forecast, int nthreads, int chunk_size) {
+											  	bool get_lpl, Eigen::MatrixXi seed_chain, Eigen::VectorXi seed_forecast, int nthreads) {
 	int num_window = y.rows();
   int dim = y.cols();
   int num_test = y_test.rows();
@@ -743,7 +741,7 @@ Rcpp::List roll_bvharldlt(Eigen::MatrixXd y, int week, int month, int num_chains
 		}
 	} else {
 	#ifdef _OPENMP
-		#pragma omp parallel for collapse(2) schedule(static, chunk_size) num_threads(nthreads)
+		#pragma omp parallel for collapse(2) schedule(static, num_chains) num_threads(nthreads)
 	#endif
 		for (int window = 0; window < num_horizon; window++) {
 			for (int chain = 0; chain < num_chains; chain++) {
@@ -789,7 +787,6 @@ Rcpp::List roll_bvharldlt(Eigen::MatrixXd y, int week, int month, int num_chains
 //' @param step Integer, Step to forecast
 //' @param y_test Evaluation time series data period after `y`
 //' @param nthreads Number of threads
-//' @param chunk_size Chunk size for OpenMP static scheduling
 //' 
 //' @noRd
 // [[Rcpp::export]]
@@ -798,7 +795,7 @@ Rcpp::List expand_bvarldlt(Eigen::MatrixXd y, int lag, int num_chains, int num_i
 											 	 	 Rcpp::List param_reg, Rcpp::List param_prior, Rcpp::List param_intercept, Rcpp::List param_init, int prior_type,
 											 	 	 Eigen::VectorXi grp_id, Eigen::VectorXi own_id, Eigen::VectorXi cross_id, Eigen::MatrixXi grp_mat,
 												 	 bool include_mean, int step, Eigen::MatrixXd y_test,
-											 	 	 bool get_lpl, Eigen::MatrixXi seed_chain, Eigen::VectorXi seed_forecast, int nthreads, int chunk_size) {
+											 	 	 bool get_lpl, Eigen::MatrixXi seed_chain, Eigen::VectorXi seed_forecast, int nthreads) {
 	int num_window = y.rows();
   int dim = y.cols();
   int num_test = y_test.rows();
@@ -1038,7 +1035,7 @@ Rcpp::List expand_bvarldlt(Eigen::MatrixXd y, int lag, int num_chains, int num_i
 		}
 	} else {
 	#ifdef _OPENMP
-		#pragma omp parallel for collapse(2) schedule(dynamic, chunk_size) num_threads(nthreads)
+		#pragma omp parallel for collapse(2) schedule(dynamic, num_chains) num_threads(nthreads)
 	#endif
 		for (int window = 0; window < num_horizon; window++) {
 			for (int chain = 0; chain < num_chains; chain++) {
@@ -1084,7 +1081,6 @@ Rcpp::List expand_bvarldlt(Eigen::MatrixXd y, int lag, int num_chains, int num_i
 //' @param step Integer, Step to forecast
 //' @param y_test Evaluation time series data period after `y`
 //' @param nthreads Number of threads
-//' @param chunk_size Chunk size for OpenMP static scheduling
 //' 
 //' @noRd
 // [[Rcpp::export]]
@@ -1093,7 +1089,7 @@ Rcpp::List expand_bvharldlt(Eigen::MatrixXd y, int week, int month, int num_chai
 											  		Rcpp::List param_reg, Rcpp::List param_prior, Rcpp::List param_intercept, Rcpp::List param_init, int prior_type,
 											  		Eigen::VectorXi grp_id, Eigen::VectorXi own_id, Eigen::VectorXi cross_id, Eigen::MatrixXi grp_mat,
 														bool include_mean, int step, Eigen::MatrixXd y_test,
-											  		bool get_lpl, Eigen::MatrixXi seed_chain, Eigen::VectorXi seed_forecast, int nthreads, int chunk_size) {
+											  		bool get_lpl, Eigen::MatrixXi seed_chain, Eigen::VectorXi seed_forecast, int nthreads) {
 #ifdef _OPENMP
   Eigen::setNbThreads(nthreads);
 #endif
@@ -1337,7 +1333,7 @@ Rcpp::List expand_bvharldlt(Eigen::MatrixXd y, int week, int month, int num_chai
 		}
 	} else {
 	#ifdef _OPENMP
-		#pragma omp parallel for collapse(2) schedule(dynamic, chunk_size) num_threads(nthreads)
+		#pragma omp parallel for collapse(2) schedule(dynamic, num_chains) num_threads(nthreads)
 	#endif
 		for (int window = 0; window < num_horizon; window++) {
 			for (int chain = 0; chain < num_chains; chain++) {
